@@ -234,9 +234,7 @@ class Sigfox:
             "lng": lng,
         }
 
-        try_add_optional_arg(
-            payload, "productCertificate", {"productCertificate": {"key": product_cert}}
-        )
+        try_add_optional_arg(payload, "productCertificate", {"key": product_cert})
 
         return self._make_api_post(make_sigfox_url("/devices"), payload)
 
